@@ -2,11 +2,10 @@ from __future__ import unicode_literals
 
 import os
 
-import mopidy
 from mopidy import config, exceptions, ext
 
 
-__version__ = '0.1.1'
+__version__ = '0.2'
 
 
 class GMusicExtension(ext.Extension):
@@ -23,11 +22,12 @@ class GMusicExtension(ext.Extension):
         schema = super(GMusicExtension, self).get_config_schema()
         schema['username'] = config.String()
         schema['password'] = config.Secret()
+        schema['deviceid'] = config.String(optional=True)
         return schema
 
     def validate_environment(self):
         try:
-            import gmusicapi
+            import gmusicapi  # noqa
         except ImportError as e:
             raise exceptions.ExtensionError('gmusicapi library not found', e)
         pass
