@@ -25,7 +25,8 @@ class GMusicBackend(pykka.ThreadingActor, base.Backend):
 
     def on_start(self):
         self.session.login(self.config['gmusic']['username'],
-                           self.config['gmusic']['password'])
+                           self.config['gmusic']['password'],
+                           self.config['gmusic']['deviceid'])
         self.library.refresh()
         self.playlists.refresh()
 
